[Python-apps-commits] r13162 - in packages/sabnzbdplus/trunk/debian/patches (1 file)
jcfp-guest at users.alioth.debian.org
jcfp-guest at users.alioth.debian.org
Wed May 4 12:24:36 UTC 2016
Date: Wednesday, May 4, 2016 @ 12:24:34
Author: jcfp-guest
Revision: 13162
Mod patch 04
Modified:
packages/sabnzbdplus/trunk/debian/patches/04_use_config_when_daemon.diff
Modified: packages/sabnzbdplus/trunk/debian/patches/04_use_config_when_daemon.diff
===================================================================
--- packages/sabnzbdplus/trunk/debian/patches/04_use_config_when_daemon.diff 2016-05-03 06:51:49 UTC (rev 13161)
+++ packages/sabnzbdplus/trunk/debian/patches/04_use_config_when_daemon.diff 2016-05-04 12:24:34 UTC (rev 13162)
@@ -1,12 +1,25 @@
# Use the normal configuration when run as a daemon
--- a/SABnzbd.py
+++ b/SABnzbd.py
-@@ -404,7 +404,7 @@
+@@ -404,20 +404,7 @@
def GetProfileInfo(vista_plus):
""" Get the default data locations """
ok = False
- if sabnzbd.DAEMON:
-+ if sabnzbd.DAEMON and sabnzbd.WIN32:
- # In daemon mode, do not try to access the user profile
- # just assume that everything defaults to the program dir
- sabnzbd.DIR_APPDATA = sabnzbd.DIR_PROG
+- # In daemon mode, do not try to access the user profile
+- # just assume that everything defaults to the program dir
+- sabnzbd.DIR_APPDATA = sabnzbd.DIR_PROG
+- sabnzbd.DIR_LCLDATA = sabnzbd.DIR_PROG
+- sabnzbd.DIR_HOME = sabnzbd.DIR_PROG
+- if sabnzbd.WIN32:
+- # Ignore Win32 "logoff" signal
+- # This should work, but it doesn't
+- # Instead the signal_handler will ignore the "logoff" signal
+- # signal.signal(5, signal.SIG_IGN)
+- pass
+- ok = True
+- elif sabnzbd.WIN32:
++ if sabnzbd.WIN32:
+ try:
+ from win32com.shell import shell, shellcon
+ path = shell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, None, 0)
More information about the Python-apps-commits
mailing list